#
# spec file for package glib-networking
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gio_real_package %(rpm -q --qf '%%{name}' --whatprovides gio)
Name:           glib-networking
Version:        2.54.1
Release:        lp151.3.3.1
Summary:        Network-related GIO modules for glib
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://www.gnome.org
Source:         https://download.gnome.org/sources/glib-networking/2.54/%{name}-%{version}.tar.xz
Source99:       baselibs.conf
Patch0:         0001-gnutls-Add-support-for-timeouts-on-GnuTLS-pulls.patch
# For directory ownership
BuildRequires:  dbus-1
BuildRequires:  intltool
BuildRequires:  libgcrypt-devel
BuildRequires:  pkgconfig
# If this BuildRequires changes because of a gio library version change, change gio_real_package accordingly
BuildRequires:  pkgconfig(gio-2.0) >= 2.45.1
BuildRequires:  pkgconfig(gnutls) >= 3.0
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(libproxy-1.0)
BuildRequires:  pkgconfig(p11-kit-1) >= 0.8
# org.gnome.system.proxy schema is used
Requires:       gsettings-desktop-schemas
Recommends:     %{name}-lang = %{version}
Supplements:    %{gio_real_package}
%{glib2_gio_module_requires}
%if !0%{?is_opensuse}
BuildRequires:  translation-update-upstream
%endif

%description
This package contains network-related GIO modules for glib.

Currently, there is only a proxy module based on libproxy.

%lang_package

%prep
%setup -q
%patch0 -p1
%if !0%{?is_opensuse}
translation-update-upstream
%endif

%build
%configure \
    --disable-static \
    --with-ca-certificates=%{_sysconfdir}/ssl/ca-bundle.pem
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}

%post
%{glib2_gio_module_post}

%postun
%{glib2_gio_module_postun}

%files
%license COPYING
%doc NEWS README
%{_libdir}/gio/modules/libgiognomeproxy.so
%{_libdir}/gio/modules/libgiognutls.so
%{_libdir}/gio/modules/libgiolibproxy.so
%{_libexecdir}/glib-pacrunner
%{_userunitdir}/glib-pacrunner.service
%{_datadir}/dbus-1/services/org.gtk.GLib.PACRunner.service

%files lang -f %{name}.lang

%changelog
* Tue May 14 2019 Vítězslav Čížek <vcizek@suse.com>
- Fix invalid TLS sessions when TLS 1.3 is used (bsc#1134795)
  * add 0001-gnutls-Add-support-for-timeouts-on-GnuTLS-pulls.patch
- Polish spec with spec-cleaner
* Fri Oct 27 2017 luc14n0@linuxmail.org
- Update to version 2.54.1:
  + gnutls: Fix using different client certs for different
    connections (bgo#781578).
  + Updated translations.
* Tue Sep 12 2017 luc14n0@linuxmail.org
- Update to version 2.54.0:
  + Updated translations.
* Fri Sep  8 2017 jengelh@inai.de
- Replace old macros and fixup RPM group.
* Tue Aug 15 2017 zaitor@opensuse.org
- Update to version 2.53.90:
  + gnutls: Stop using %%LATEST_RECORD_VERSION in priority string,
    since that gives better compatibility with current gnutls /
    current real world (bgo#782218).
  + gnutls: Provide a better error message when a TLS alert is
    received (bgo#782218).
  + Updated translations.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 2.50.0:
  + Updated translations.
* Tue Aug 16 2016 dimstar@opensuse.org
- Update to version 2.49.90:
  + Ported to use upstream gettext rather than
    intltool/glib-gettext (bgo#768708).
  + Updated po files for future gettext versions.
  + Fixed translation lookup on Windows (bgo#765466).
  + Updated translations.
* Tue May 17 2016 mgorse@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Mon May  9 2016 zaitor@opensuse.org
- Update to version 2.48.2:
  + gnutls: Fixed an infinite loop if a server sent two identical
    copies of its CA certificate (bgo#765317).
  + Updated translations.
* Tue Apr 26 2016 zaitor@opensuse.org
- Update to version 2.48.1:
  + Fixed translations in non-UTF-8 domains (bgo#765466).
  + Fixed bash-ism in configure (bgo#765396).
  + Updated translations.
- Stop passing V=1 to make, we do debugging locally.
- Add default http://www.gnome.org as Url: Silence rpmlint.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 2.48.0:
  + New stable release. (No changes since 2.47.90).
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 2.47.90:
  + gnutls: The non-PKCS#11 TLS plugin now uses gnutls's
    certificate validation code directly, rather than attempting to
    build a certificate chain itself first (bgo#753260 and others).
  + gnutls: Fixed a leak when closing a connection during an
    implicit handshake (bgo#736809).
  + gnutls: Fixed "make check" without PKCS#11 support
    (bgo#728977).
  + gnutls: Various changes in preparation for DTLS support (but
    not the actual DTLS support itself) (bgo#697908, bgo#735754).
  + Updated translations.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 2.47.1:
  + Added a systemd service file for glib-pacrunner (bgo#755740).
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 2.46.1:
  + Fixed a certificate chain validation problem that affected
    Facebook in Epiphany (bgo#750457).
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 2.46.0:
  + Various minor cleanups and small memory leak fixes.
  + Added a new test case for client certificate chain handling
    (bgo#754129).
  + Updated translations.
* Fri May  1 2015 zaitor@opensuse.org
- Update to version 2.45.1:
  + tls/gnutls: Implement
    g_tls_client_connection_copy_session_state(), to allow
    implementing FTP-over-TLS in gvfs (bgo#745255).
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 2.44.0:
  + Stable release, no changes since 2.43.92.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 2.43.92:
  + Fix TLS session caching when using session tickets
    (bgo#745099).
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 2.43.91:
  + tls/gnutls: Removed a workaround for connecting to servers with
    weak DH parameters, which was apparently only needed because
    gnutls was prioritizing DHE over RSA (rh#1177964#c8).
  + tls/gnutls: We now require gnutls 3.x again. (In fact, 2.42.1
    and 2.43.1 accidentally used a 3.x-only function, so we already
    required it, we were just failing to declare that fact).
  + tls/tests: Skip certain tests when running against old gnutls
    or GLib releases. (glib-networking 2.43.91 itself does not
    require GLib 2.43, but one of the test cases does).
  + Updated translations.
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 2.43.1:
  + The GTlsClientConnection "use-ssl3" property now falls back to
    TLS 1.0 if SSL 3.0 has been disabled, rather than just failing.
    Also, we now use the gnutls %%LATEST_RECORD_VERSION option by
    default (to allow connecting to certain servers that were
    incorrectly patched for the POODLE attack), but also make sure
    to remove that option in the fallback ("use-ssl3") mode (to
    allow connecting to other servers that are differently broken)
    (bgo#738633, bgo#740087).
  + tls/gnutls: Miscellaneous warning, debugging, and leak fixes
    (bgo#736757, bgo#736809, bgo#737106).
  + Updated translations.
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 2.42.1:
  + The GTlsClientConnection "use-ssl3" property now falls back to
    TLS 1.0 if SSL 3.0 has been disabled, rather than just failing.
    Also, we now use the gnutls %%LATEST_RECORD_VERSION option by
    default (to allow connecting to certain servers that were
    incorrectly patched for the POODLE attack), but also make sure
    to remove that option in the fallback ("use-ssl3") mode (to
    allow connecting to other servers that are differently broken).
    (bgo#738633, bgo#740087).
  + tls/gnutls: Miscellaneous warning, debugging, and leak fixes
    (bgo#736757, bgo#736809, bgo#737106).
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 2.42.0:
  + New stable release. (No changes since 2.41.92).
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 2.41.92:
  + tls/gnutls:
  - Incorrectly-ordered certificate chains are now accepted
    (bgo#683266).
  - Closing an already-closed GTlsConnection now correctly
    returns TRUE rather than G_IO_ERROR_CLOSED (bgo#735754).
* Tue Jul 22 2014 dimstar@opensuse.org
- Update to version 2.41.4:
  + tls/gnutls: certificates with IP address subject altnames are
    now supported (bgo#726596).
  + tls/tests: added a script to re-generate the certificates, and
    regenerated them (since the key for the existing CA certificate
    had been lost, so it wasn't possible to add new test
    certificates, eg, for IP SAN) (bgo#733365).
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 2.41.3:
  + tls/gnutls: If a server's certificate includes an issuer chain,
    we now send the entire chain to the client (bgo#724708).
  + Updated translations.
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 2.40.1:
  + tls/gnutls: g_tls_backend_get_default_database() should never
    return %%NULL; if glib-networking was built without a
    ca-certificates file, then the default GTlsDatabase should just
    be empty (bgo#727282).
* Tue Mar 25 2014 dimstar@opensuse.org
- Update to version 2.40.0:
  + New stable release. No changes since 2.39.90.
* Wed Feb 19 2014 zaitor@opensuse.org
- Update to version 2.39.90:
  + tls/gnutls:
  - Avoid trying to update a destroyed GSource (bgo#723774).
  - Fix another flaky test (bgo#722336).
  + tests: use the TAP driver.
  + Updated translations.
* Mon Dec 16 2013 dimstar@opensuse.org
- Update to version 2.39.3:
  + tls/tests: Fix one sporadic bug in the connection test
    (bgo#720081) and make it properly fail rather than hanging
    forever when another sporadic bug happens (which I don't
    actually know the cause of) (bgo#719727).
  + tls/gnutls: Fix for -Werror=format-nonliteral (bgo#720081).
* Thu Nov 21 2013 dimstar@opensuse.org
- Update to version 2.39.1:
  + tls/gnutls:
  - Use g_tls_interaction_invoke_request_certificate()
    when processing a certificate request (bgo#637257).
  - Handle G_IO_ERROR_TIMED_OUT on a GTlsConnection correctly
    rather than reporting "The specified session has
    been invalidated for some reason" (bgo#710700).
  - add a test for a fix made in glib (bgo#710691).
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 2.38.2 (bnc#849913):
  + Fix to previous installed-tests fix, which resulted in some
    files getting installed even when installed tests weren't
    enabled (bgo#710197).
- Drop "Cleanup wrongly installed /files directory".
* Tue Oct 15 2013 dimstar@opensuse.org
- Update to version 2.38.1:
  + glibpacrunner: Don't crash if there is an internal libproxy
    error (rh#866927).
  + tls/tests: Fix installed tests to not accidentally depend on
    having the source tree still exist (bgo#709628).
  + Updated translations.
- Cleanup wrongly installed /files directory (bgo#710197).
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 2.38.0:
  + New stable release (No changes since 2.37.5).
* Wed Aug 28 2013 dimstar@opensuse.org
- Revert the changes from Jul 11 to not use certs.pem:
  + No longer pass --with-pkcs and --without-ca-certificate to
    configure, but instead pass
  - -with-ca-certificates=/etc/ssl/ca-bundle.pem.
  + Drop glib-networking-fix-no-cert-bundles.patch: the patch
    causes side-effects, as discovered in bnc#825903).
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 2.37.5:
  + gnutls: minimum version is now 2.12.8 (with 3.x preferred...).
  + glib-networking now supports the --enable-installed-tests flag,
    to install its test programs to run at other times (ie, after
    updating glib).
* Thu Jul 11 2013 dimstar@opensuse.org
- Build using system pkcs#11 certificate store instead of using
  /etc/ssl/certs.pem:
  + Pass the following parameters to configure
  - -with-pkcs
  - -without-ca-certificate
  + Add glib-networking-fix-no-cert-bundles.patch: do not fail if
    no certificate bundle (anchor) is specified.
* Tue Jul  9 2013 dimstar@opensuse.org
- Update to version 2.37.4:
  + bgo#701377: proxy/gnome: further improve GNOME session
    detection.
  + bgo#701693: gnutls: don't crash if $G_TLS_GNUTS_PRIORITY is
    invalid.
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 2.37.2:
  + proxy/gnome: Improve session-type detection to include
    gnome-classic and anything else starting with "gnome"
    (bgo#700607).
  + proxy/libproxy: make SOCKS work when using the async API
    (bgo#699359).
  + proxy/tests: make the libproxy test program use the just-built
    plugin rather than the installed one (bgo#700286).
  + proxy/tests: fix to not error out if neither proxy module is
    built (bgo#700628).
  + tls/tests: fix a sporadic crash.
* Wed May  1 2013 dimstar@opensuse.org
- Update to version 2.37.1:
  + gnutls:
  - bgo#695062: Fixed a hang while rehandshaking with gnutls 3.x.
  - bgo#697754: Fixed a handshaking crash in multithreaded use.
  + proxy/gnome:
  - Fix "automatic" mode, which was mistakenly being treated as
    "none".
  - bgo#698936: Use this in Unity sessions as well as GNOME ones.
  + Updated translations.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 2.36.1:
  + gnutls: Fixed a bug that could cause hangs and/or bursts of CPU
    usage in some cases (bgo#696881).
  + gnutls: Fixed CFLAGS when building with gnutls in a different
    prefix (bgo#696519).
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 2.36.0:
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 2.35.9:
  + Fixed one kind of handshake failure to return the correct error
    code under gnutls 3.x (bgo#694812).
  + Updated translations.
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 2.35.8:
  + proxy/gnome: ported to new GSimpleProxyResolver, and added more
    tests.
  + gnutls: Fixed a small per-connection leak (bgo#693718).
  + tls/tests: Fixed several race conditions that caused spurious
    failures (bgo#693720).
  + Updated translations.
* Tue Feb  5 2013 dimstar@opensuse.org
- Update to version 2.35.6:
  + proxy/gnome: Fixed several bugs:
  - Multithreaded usage could result in crashes.
  - In "automatic" mode, synchronous lookups would obey
    ignore-hosts, but asynchronous lookups would not.
  - lookup_async() would never notice if the proxy settings
    switched from "automatic" to "manual" or "none" (and would
    make a synchronous D-Bus call when switching in the other
    direction).
  - If given an invalid URI, lookup_async() would return a
    successful result (and leak the GError that it was supposed
    to have returned), and lookup() would return both the error
    and the proxy (leaking one or the other, depending on how
    the caller behaved).
  + Updated translations.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 2.35.4:
  + proxy/gnome: The tests should now work correctly even if run
    from a non-GNOME environment.
  + Updated translations.
* Tue Jan  8 2013 dimstar@opensuse.org
- Update to version 2.35.3:
  + build: The TLS tests are now not built if you are building
    without gnutls support.
  + gnutls: Several handshaking fixes:
  - Fix a hang when doing a synchronous close() immediately
    after cancelling an asynchronous handshake() (which would
    happen in libsoup if you cancelled a message at the right
    time) (bgo#688751)
  - Avoid an assertion when an implicit handshake fails
    (bgo#689274)
  - Fixed GTlsServerConnection:authentication-mode to work
    again, and added a regression test for this (bgo#689259)
  - Return the appropriate error
    (G_TLS_ERROR_CERTIFICATE_REQUIRED) when a handshake fails
    because the server required a certificate but none was
    provided, and added a test for this (bgo#689260)
  - Make g_io_stream_close() finish successfully after a failed
    handshake (bgo#689260)
  - Make g_io_stream_close() finish successfully before a
    handshake (bgo#689271)
  + gnutls: Updated to be aware of G_IO_ERROR_BROKEN_PIPE in glib
    2.35.3, which needs to be converted to G_TLS_ERROR_NOT_TLS in
    some cases. (Previously this error showed up as just
    G_IO_ERROR_FAILED.)
  + proxy/gnome: This is now only used in GNOME login sessions (as,
    essentially, a more efficient version of the libproxy GNOME
    backend); in non-GNOME sessions, gio will now fall back to the
    libproxy plugin, allowing environment variables or other
    libproxy settings backends to be used.
  + Updated translations.
* Fri Nov 16 2012 dimstar@opensuse.org
- Update to version 2.35.1:
  + Update for glib 2.35.1; remove g_type_init() calls and port to
    GTask.
  + Updated translations.
* Thu Nov 15 2012 dimstar@opensuse.org
- Update to version 2.34.2:
  + build: it no longer tries to build the TLS tests if gnutls is
    not available.
  + Updated translations.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 2.34.0:
  + Updated translations.
* Mon Sep 17 2012 zaitor@opensuse.org
- Update to version 2.33.14:
  + Updated translations.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 2.33.12:
  + gnutls: Revert the addition of the certificate-bytes and
    private-key-bytes properties to GTlsCertificateGnutls, since
    they were reverted in glib (bgo#682081)
  + Updated translations.
* Tue Aug 21 2012 dimstar@opensuse.org
- Update to version 2.33.10:
  + gnutls:
  - Improved the certificate verifying code to deal with the case
    of a CA being reissued with the same key but a different
    signature algorithm. (bgo#681299)
  - Fixed an uninitialized variable in
    g_tls_connection_gnutls_close(). (bgo#681636)
  + Updated translations.
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 2.33.8:
  + gnutls:
  - If a GTlsConnection gets an error when handshaking, it will
    now continue to return that error message on future I/O
    attempts, rather than behaving in an undefined manner
  - You can now read from a GTlsConnection's input stream and
    write to its output stream at the same time (either in
    different threads, or asynchronously in a single thread).
    (bgo#660252)
  + Updated translations.
* Tue Jun 26 2012 dimstar@opensuse.org
- Update to version 2.33.3:
  + Updated autogen.sh (in particular to support automake 1.12)
    (bgo#675261)
  + gnutls: fix the use-system-certdb property on
    GTlsConnectionGnutls
  + Updated translations.
* Wed May 16 2012 dimstar@opensuse.org
- Update to version 2.33.2:
  + gnutls: simplify using new glib pollable stream methods
  + proxy/gnome: fix a bug that made it impossible to use SOCKS
    without also having a separate http proxy.
* Tue May 15 2012 vuntz@opensuse.org
- Update to version 2.32.3:
  + proxy/gnome: Fix SOCKS to work when no http proxy is set
  + Updated translations.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 2.32.1:
  + gnutls: Added /etc/ssl/ca-bundle.pem to the list of files to
    check for to use as the default CA list (bgo#673944)
  + Updated translations.
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 2.32.0:
  + Updated translations.
* Tue Mar 20 2012 vuntz@opensuse.org
- Update to version 2.31.22:
  + Updated translations.
* Tue Mar  6 2012 vuntz@opensuse.org
- Update to version 2.31.20:
  + gnutls: Fixed a linking problem on some platforms when PKCS#11
    is enabled (bgo#670956)
  + Updated translations.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 2.31.16:
  + gnutls: Fixed a TLS handshaking bug that in particular caused
    lots of crashes in epiphany (bgo#658771)
  + tls/tests: Fixed a bug in the pkcs11-pin test that could cause
    it to spuriously fail
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 2.31.6:
  + gnutls:
  - Support gnutls built against nettle instead of gcrypt
    (bgo#657306)
  - Implement TLS session caching for GTlsServerConnection
    (bgo#636574)
  + tls/tests: Explicitly request the memory GSettings backend, to
    avoid warnings in partial jhbuild environments.
  + proxy/gnome: Update to use GInetAddressMask.
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Tue Nov 22 2011 dimstar@opensuse.org
- Update to version 2.31.2:
  + gnutls:
  - Added gnutls-pkcs11 backend, which uses gnutls 2.12.8 and
    p11-kit (a new optional dependency) to provide access to
    PKCS#11 tokens. At the moment, this is only enabled if you
    set GIO_USE_TLS=gnutls-pkcs11 in the environment (bgo#656361)
  - GTlsCertificateGnutls can now read unencrypted PKCS#8 keys
    (which show "BEGIN PRIVATE KEY" in PEM form) in addition to
    the previously-supported PKCS#1 keys ("BEGIN RSA PRIVATE
    KEY").
  + Updated translations.
- Add pkgconfig(p11-kit-1) BuildRequires. New dependency.
* Tue Nov 15 2011 dimstar@opensuse.org
- Really enable parallel build: fix typo smp_flags => smp_mflags.
* Thu Oct 27 2011 dimstar@opensuse.org
- Update to version 2.31.0:
  + Integrate fixes from 2.30.1.
  + gnutls:
  - Bumped required GNUTLS version to 2.11.0 and updated code for
    that (bgo#656903).
  - Added another G_TLS_ERROR_NOT_TLS (aka "dumb server, try
    falling back from TLS to SSLv3") case, when the handshake
    completes but then packets after that don't decrypt
    correctly (bgo#662104).
  - Made sure that GTlsConnection:peer-certificate and
    :peer-certificate-errors get set even when the peer
    certificate is rejected.
  + proxy/gnome: build fixes (bgo#662203, bgo#662085).
  + Updated translations.
* Tue Oct 18 2011 vuntz@opensuse.org
- Update to version 2.30.1:
  + Fixed a crash when passing a NULL GCancellable to
    g_tls_connection_close_async() (bgo#659786)
  + Fixed ignore_hosts handling in GProxyResolverGnome (bgo#655581)
  + Fixed handling of self-signed CA certificates in
    GTlsDatabaseGnutls (bgo#660508)
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 2.30.0:
  + Updated translations.
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 2.29.92:
  + gnutls:
  - Fixed a problem when linking against GNUTLS 3.0, where
    connections would sometimes return the error "The TLS
    connection was non-properly terminated". (bgo#659233)
  - Plugged a few memory leaks
  + Updated translations.
* Wed Aug 31 2011 vuntz@opensuse.org
- Update to version 2.29.18:
  + gnutls:
  - fixed two rehandshaking bugs; one in which a client would
    erroneously report an error after successfully rehandshaking
    (bgo#653645), and one where initiating an asynchronous
    rehandshake on the server side would send illegal packets and
    cause the client to disconnect.
  - made GTlsDatabaseGnutls and GTlsFileDatabaseGnutls properly
    cancellable
  - fixed the client-side session cache to not share session IDs
    between different virtual hosts on the same IP address, which
    caused problems with some servers. (bgo#581342)
  + tls: Fixed up the tls test program so it can be run from "make
    check"
  + Updated translations.
* Thu Aug 25 2011 dimstar@opensuse.org
- Add libgcrypt-devel BuildRequires: gnutls used to bring this in
  as a dependency for us.
* Tue Aug 16 2011 dimstar@opensuse.org
- Update to version 2.29.15:
  + bgo#636572: gnutls: implement GTlsDatabase
  + bgo#652284: gnutls: override minimum key length, to allow
    connecting to HTTP servers with very small keys
  + bgo#581342: gnutls: use %%COMPAT mode, which makes GNUTLS behave
    more like OpenSSL/NSS/Windows in a few ways, making it work
    with certain broken HTTP servers.
  + gnutls: fixed a crash when passed a NULL GError.
* Wed Jul  6 2011 vuntz@opensuse.org
- Change rpm query to look for the real package containing gio to
  use the new gio virtual name, that is now provided by the package
  containing the gio library. This is better than the query on the
  library filename, which might change later.
- Also properly escape the queryformat, since we need to double the
  %% characters in a .spec file.
* Tue Jul  5 2011 vuntz@opensuse.org
- Update to version 2.29.9:
  + Optimized GDBus usage in PACRunner.
  + Fixed a race condition in GProxyResolverGnome.
  + Changed configure to --enable-maintainer-mode by default,
    to match glib.
  + Updated translations.
* Fri Jun 17 2011 vuntz@opensuse.org
- Fix build after glib libraries moved back to %%{_libdir}.
* Mon May 23 2011 dimstar@opensuse.org
- Update to version 2.28.7:
  + Fixed a race condition in GProxyResolverGnome that caused
    problems when making simultaneous connections from multiple
    threads.
  + Updated translations.
* Wed May  4 2011 alinm.elena@gmail.com
- Add gsettings-desktop-schemas Requires as the proxy schemas are
  used.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 2.28.6.1:
  + Fixed a bug in the gnutls backend introduced in 2.28.6
* Tue Apr 26 2011 fcrozat@novell.com
- Update to version 2.28.6:
  + Fixed some links in the gnutls backend.
  + Updated translations.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 2.28.5:
  + Updated translations.
* Tue Mar 22 2011 fcrozat@novell.com
- Update to version 2.28.4:
  + Added a new proxy backend, GProxyResolverGnome, that uses
    GSettings and the network proxy schemas from
    gsettings-desktop-schemas to provide proxy information (and
    using a new D-Bus service provided by the libproxy backend to
    provide PAC/WPAD support).
  + Updated translations.
- Changes from version 2.28.0:
  + Build fix.
  + Updated translations.
- Add dbus-1 and pkgconfig(gsettings-desktop-schemas)
  BuildRequires. dbus-1 is only needed for directory ownership.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Fri Jan  7 2011 vuntz@opensuse.org
- Update to version 2.27.90:
  + Fixed configure script to actually error out if installed glib
    version is too old
  + gnutls:
  - updated GTlsClientConnectionGnutls for :accepted-cas type
    change
  - fixed an uninitialized variable
* Wed Dec 22 2010 vuntz@opensuse.org
- Update to version 2.27.5:
  + gnutls:
  - finish implementing GTlsRehandshakeMode, which was present
    but non-functional in 2.27.4
  - updates for glib TLS API changes
  - fix some async bugs that caused the main loop to spin
  - implement a client-side session cache, to speed up handshakes
  + Compile with gcc warnings by default
* Tue Dec  7 2010 vuntz@opensuse.org
- Update to version 2.27.4:
  + Add GNUTLS-based implementation of GTlsBackend.
- Add pkgconfig(gnutls) BuildRequires, and pass
  - -with-ca-certificates=/etc/ssl/ca-bundle.pem to configure.
* Wed Oct 13 2010 vuntz@opensuse.org
- Update to version 2.26.0:
  + No changes, just a version bump.
- Update spec file after move of glib libraries to /lib: we are
  checking the name of the package providing libgio by looking at
  the provider of the file.
* Mon Oct 11 2010 vuntz@opensuse.org
- Add missing Requires for glib2-tools to glib-networking in
  baselibs.conf.
* Tue Aug 31 2010 vuntz@opensuse.org
- Initial packaging (version 2.25.0)
